@@ -69,26 +69,25 @@ def run_forecast_ensemble(
         named_model_list = model_list
     else:
         named_model_list = [
-            "GreyKite",
-            "FBProphet",
-            "Naive",
-            "XGBoost",
-            "RandomForest",
-            "SARIMA"
+            "greykite",
+            "prophet",
+            "naive",
+            "xgboost",
+            "randomforest",
+            "sarima"
         ]
 
     # For each model, run a full evaluation and add to the ensemble results
     ensemble = []
     for model_name in named_model_list:
         print(f"    Running --{model_name}")
-        model_dict = {"name": model_name}
         model = initialize_model(model_name)
         model_dict = model.evaluate(
             dataframe=df,
             train_end_date=train_end_date,
             frequency=frequency,
             forecast_period_list=period_list)
-        weight = model_dict["r2"]
+        weight = model_dict["performance_metrics"]["r2"]
         if weight < 0:
             weight = 0
         elif model_name == "Naive":
@@ -150,25 +149,31 @@ def run_forecast_ensemble(
     return_columns = ["y"] + forecast_columns
     return_dataframe = return_dataframe[return_columns]
 
-    degraded_accuracies = {}
-    training_years = (df[DATE_COLUMN_NAME].max() - df[DATE_COLUMN_NAME].min()).days / 365
-    for year in range(1, forecast_horizon_years + 1):
-        multiplier = 1.0
-        years_outside_of_training = max(year - training_years, 0)
-        if years_outside_of_training > 0:
-            for yy in range(1, int(year) + 1):
-                if yy > (2 * training_years):
-                    multiplier *= 0.5
-                elif yy > training_years:
-                    multiplier *= 0.95
-        degraded_accuracies[year] = multiplier * consolidated_metrics["accuracy"]
-
+    # Add ensemble to list
     ensemble.append({
         "name": "ensemble",
         "ensemble_dataframe": return_dataframe,
         "performance_metrics": performance_metrics,
-        "consolidated_metrics": consolidated_metrics,
-        "degraded_accuracies": degraded_accuracies
+        "consolidated_metrics": consolidated_metrics
     })
 
+    # Create degraded accuracies for all models
+    training_years = (df[DATE_COLUMN_NAME].max() - df[DATE_COLUMN_NAME].min()).days / 365
+    for model in ensemble:
+        degraded_accuracies = {}
+        degraded_fit = {}
+        for year in range(1, forecast_horizon_years + 1):
+            multiplier = 1.0
+            years_outside_of_training = max(year - training_years, 0)
+            if years_outside_of_training > 0:
+                for yy in range(1, int(year) + 1):
+                    if yy > (2 * training_years):
+                        multiplier *= 0.5
+                    elif yy > training_years:
+                        multiplier *= 0.95
+            degraded_accuracies[year] = multiplier * model["consolidated_metrics"]["accuracy"]
+            degraded_fit[year] = multiplier * model["consolidated_metrics"]["fit"]
+        model["degraded_accuracies"] = degraded_accuracies
+        model["degraded_fit"] = degraded_fit
+
     return ensemble
