@@ -46,9 +46,9 @@ class BaseModel:
             train_end=train_end_date,
             frequency=frequency,
             forecast_period_list=forecast_period_list)
-        result_package = utils.get_model_statistics(y=actual, yhat=predicted)
-        result_package.update(utils.consolidate_scores(result_package, actual.mean()))
-        result_package["name"] = self.__name__
+        result_package = {"name": self.__name__}
+        result_package["performance_metrics"] = utils.get_model_statistics(y=actual, yhat=predicted)
+        result_package["consolidated_metrics"] = utils.consolidate_scores(result_package["performance_metrics"], actual.mean())
         result_package["forecast_dataframe"] = pd.DataFrame(
                 index=pd.Series(forecast.index),
                 data={f"forecast_values_{self.__name__}": pd.Series(forecast).values})
@@ -67,7 +67,7 @@ class GreyKite(BaseModel):
     def __init__(self):
         """Initializes greykite model"""
         super().__init__()
-        self.__name__ = "GreyKite"
+        self.__name__ = "greykite"
         self.metadata = MetadataParam(
             time_col=DATE_COLUMN_NAME,
             value_col=VALUE_COLUMN_NAME)
@@ -115,7 +115,7 @@ class FBProphet(BaseModel):
     def __init__(self):
         """Initializes prophet model"""
         super().__init__()
-        self.__name__ = "FBProphet"
+        self.__name__ = "prophet"
 
     def run(self, dataframe: pd.DataFrame, train_end: datetime, frequency: str, forecast_period_list: list) -> tuple:
         """Runs rolling prediction using the model to return actual and predicted values
@@ -147,7 +147,7 @@ class Naive(BaseModel):
     def __init__(self):
         """Initializes naive model"""
         super().__init__()
-        self.__name__ = "Naive"
+        self.__name__ = "naive"
         self.growth_comparison_period_in_years = 1
         self.minimum_training_years = 2
 
@@ -157,29 +157,76 @@ class Naive(BaseModel):
         train_mask = dataframe[DATE_COLUMN_NAME] <= train_end
         dataframe_test = dataframe[~train_mask]
 
-        def run_prediction(prediction_date, frequency):
-            base_growth_period_start = prediction_date - (2 * comparison_period_relativedelta)
-            comparison_growth_period_start = prediction_date - comparison_period_relativedelta
-
+        def get_growth(dataframe, base_start, base_end, comparison_start, comparison_end):
             # Calculate base period totals
             base_growth_period_mask = \
-                (dataframe[DATE_COLUMN_NAME] >= base_growth_period_start) & \
-                (dataframe[DATE_COLUMN_NAME] < comparison_growth_period_start)
+                (dataframe[DATE_COLUMN_NAME] >= base_start) & \
+                (dataframe[DATE_COLUMN_NAME] < base_end)
             base_growth_period_sum = dataframe.loc[base_growth_period_mask, VALUE_COLUMN_NAME].sum()
 
             # Calculate comparison period totals
             comparison_growth_period_mask = \
-                (dataframe[DATE_COLUMN_NAME] >= comparison_growth_period_start) & \
-                (dataframe[DATE_COLUMN_NAME] < prediction_date)
+                (dataframe[DATE_COLUMN_NAME] >= comparison_start) & \
+                (dataframe[DATE_COLUMN_NAME] < comparison_end)
             comparison_growth_period_sum = dataframe.loc[comparison_growth_period_mask, VALUE_COLUMN_NAME].sum()
             # Determine growth_rate as the total change in volume from the base period to the comparison period
             growth_rate = comparison_growth_period_sum / base_growth_period_sum
 
-            # Determine value to use as the base for the estimation
-            if frequency == "W-MON":
-                comparison_growth_period_start = comparison_growth_period_start - relativedelta(days=(comparison_growth_period_start.weekday()))
-            previous_value_mask = dataframe[DATE_COLUMN_NAME] == comparison_growth_period_start
-            previous_value = dataframe.loc[previous_value_mask, VALUE_COLUMN_NAME].sum()
+            return growth_rate
+
+        def run_prediction(prediction_date, frequency):
+            training_dataframe = dataframe[dataframe[DATE_COLUMN_NAME] < prediction_date]
+
+            # Handle cases where less data is available
+            available_comparison_period = training_dataframe[DATE_COLUMN_NAME].max() - training_dataframe[DATE_COLUMN_NAME].min()
+            available_comparison_years = available_comparison_period / np.timedelta64(1, 'Y')
+            if available_comparison_years < self.minimum_training_years:
+                if available_comparison_years > 1:
+                    # Handle rolling comparison
+                    # Use defaults if that amount of time is available
+                    base_growth_period_start = training_dataframe[DATE_COLUMN_NAME].min()
+                    base_growth_period_end = prediction_date + relativedelta(years=-1)
+                    comparison_growth_period_start = base_growth_period_start + relativedelta(years=1)
+
+                    # Previous value comes from the day after the base_growth period ends
+                    growth_rate = get_growth(
+                        dataframe=training_dataframe,
+                        base_start=base_growth_period_start,
+                        base_end=base_growth_period_end,
+                        comparison_start=comparison_growth_period_start,
+                        comparison_end=prediction_date
+                    )
+                    # Get date after end of base period
+                    base_mask = training_dataframe[DATE_COLUMN_NAME] < base_growth_period_end
+                    previous_date = training_dataframe[~base_mask][DATE_COLUMN_NAME].min()
+                    previous_value_mask = dataframe[DATE_COLUMN_NAME] == previous_date
+                    previous_value = dataframe.loc[previous_value_mask, VALUE_COLUMN_NAME].sum()
+
+                else:
+                    # Growth is linear from beginning to end
+                    start_value = training_dataframe.loc[training_dataframe[DATE_COLUMN_NAME] == training_dataframe[DATE_COLUMN_NAME].min(), VALUE_COLUMN_NAME].sum()
+                    end_value = training_dataframe.loc[training_dataframe[DATE_COLUMN_NAME] == training_dataframe[DATE_COLUMN_NAME].max(), VALUE_COLUMN_NAME].sum()
+                    growth_rate = (((end_value - start_value) / len(training_dataframe)) / end_value) + 1
+                    previous_value = end_value
+            # Otherwise we can use a normal y/y comparison
+            else:
+                # Use defaults if that amount of time is available
+                base_growth_period_start = prediction_date - (2 * comparison_period_relativedelta)
+                comparison_growth_period_start = prediction_date - comparison_period_relativedelta
+
+                growth_rate = get_growth(
+                    dataframe=dataframe,
+                    base_start=base_growth_period_start,
+                    base_end=comparison_growth_period_start,
+                    comparison_start=comparison_growth_period_start,
+                    comparison_end=prediction_date
+                )
+
+                # Determine value to use as the base for the estimation
+                if frequency == "W-MON":
+                    comparison_growth_period_start = comparison_growth_period_start - relativedelta(days=(comparison_growth_period_start.weekday()))
+                previous_value_mask = dataframe[DATE_COLUMN_NAME] == comparison_growth_period_start
+                previous_value = dataframe.loc[previous_value_mask, VALUE_COLUMN_NAME].sum()
 
             return previous_value * growth_rate
 
@@ -221,7 +268,7 @@ class XGBoost(BaseModel):
     def __init__(self):
         """Initializes xgboost model"""
         super().__init__()
-        self.__name__ = "XGBoost"
+        self.__name__ = "xgboost"
 
     def create_time_series_features(self, time_series_df, frequency, backtest=False):
         result_df = time_series_df.copy()
@@ -356,7 +403,7 @@ class RandomForest(BaseModel):
     def __init__(self):
         """Initializes random forest model"""
         super().__init__()
-        self.__name__ = "RandomForest"
+        self.__name__ = "randomforest"
 
     def create_time_series_features(self, time_series_df, frequency, backtest=False):
         result_df = time_series_df.copy()
@@ -445,7 +492,6 @@ class RandomForest(BaseModel):
 
         return predictions
 
-
     def run(self, dataframe: pd.DataFrame, train_end: datetime, frequency: str,
             forecast_period_list: pd.DataFrame) -> tuple:
         dataframe = dataframe.copy()
@@ -484,12 +530,13 @@ class RandomForest(BaseModel):
 
         return test[VALUE_COLUMN_NAME], predicted, forecast_predictions
 
+
 class SARIMA(BaseModel):
 
     def __init__(self):
         """Initializes SARIMA model"""
         super().__init__()
-        self.__name__ = "SARIMA"
+        self.__name__ = "sarima"
 
     def run(self, dataframe: pd.DataFrame, train_end: datetime, frequency: str, forecast_period_list: list) -> tuple:
         dataframe = dataframe.copy()
@@ -510,7 +557,17 @@ class SARIMA(BaseModel):
         predicted = pd.DataFrame()
         previous_index = 0
         period_horizon = len(forecast_period_list)
-        for ii in range(period_horizon, len(test), period_horizon):
+
+        if period_horizon <= len(test):
+            start = period_horizon
+            end = len(test)
+            step = period_horizon
+        else:
+            start = len(test)
+            end = len(test) + 1
+            step = len(test)
+        backtest_range = range(start, end, step)
+        for ii in backtest_range:
             model = SARIMAX(train, order=(1, 1, 2), seasonal_order=(1, 1, 2, m))
             results = model.fit(method='powell')
 
@@ -519,14 +576,14 @@ class SARIMA(BaseModel):
             previous_index = ii
 
             # Create predictions and add to list
-            predictions = pd.DataFrame(index=test_subset.index, data=results.forecast(steps=period_horizon).values)
+            predictions = pd.DataFrame(index=test_subset.index, data=results.forecast(steps=step).values)
             predicted = pd.concat([predicted, predictions])
 
             # Update training dataset
             train = pd.concat([train, test_subset])
 
             # Handle final test records
-            if (len(test) - ii) < period_horizon:
+            if ((len(test) - ii) < step) & (len(test) - ii > 0):
                 model = SARIMAX(train, order=(1, 1, 2), seasonal_order=(1, 1, 2, m))
                 results = model.fit(method='powell')
 
